@@ -14,8 +14,9 @@ from analysis_runner import dataproc
 from joint_calling import utils
 from joint_calling.vqsr import make_vqsr_jobs
 
-logger = logging.getLogger('joint-calling')
-logger.setLevel('INFO')
+logger = logging.getLogger(__file__)
+logging.basicConfig(format='%(levelname)s (%(name)s %(lineno)s): %(message)s')
+logger.setLevel(logging.INFO)
 
 
 def add_variant_qc_jobs(
